/*
   	Tairo v0.61
    Copyright (C) 2004 Jonas Gehring
        
    Tairo is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
    as published by the Free Software Foundation; either version 2
    of the License, or (at your option) any later version.

    Tairo is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Tairo; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
*/

// C Source File
// Created 30.10.04; 12:27:06

// Own headers
#include "tairo.h"						// Constants, proto-types etc.
// Biult-in headers
#include <alloc.h>						// Routines for dynamic memory allocation
#include <graph.h>						// Common (non-windowed) graphic routines
#include <gray.h>							// Routines for grayscale graphics
#include <statline.h>					// Routines for manipulation of the status line
#include <kbd.h>							// Keyboard handling routines
#include <mem.h>							// Routines for manipulation of memory blocks
#include <stdio.h>						// ANSI-compatible file and TTY input/output routines
#include <intr.h>							// Routines for creating interrupt handlers
#include <stdlib.h>						// Some useful routines proposed by ANSI (sorting, searching, etc.)
#include <system.h>						// System routines (for accessing system timers, queues, etc.)
// Other headers
#include "extgraph.h"					// Include ExtGraph v2.00beta4 by TI-Chess Team


// Some globals, because we have one function for entering and one for leaving
LCD_BUFFER *screen;
INT_HANDLER save_int_1;
INT_HANDLER save_int_5;


// Exits the game
void ExitTairo(void)
{
	// Turn off grayscale mode	
	GrayOff();
	
	// Save data to file and quit
	Save(&savload);
	
	// Enable tha Auto-Ints again
	SetIntVec(AUTO_INT_1, save_int_1);
	SetIntVec(AUTO_INT_5, save_int_5);
	ClearGrayScreen();
	LCD_restore(screen);
	HeapFreePtr(screen); 
	
	ST_helpMsg("Tairo v0.61 by saubue");
	
	while (_rowread(0)) continue;
	
	// Quit the program
	exit(0);
}


// Main Function
void _main(void)
{
	short key;
	BOOL mode;
	START_OPTIONS options;
	
	// Allocate memory for saving the screen
	if ((screen = malloc(sizeof(LCD_BUFFER))) == NULL) {
		ST_helpMsg("Out of memory");
		return;
	}
	
	save_int_1 = GetIntVec(AUTO_INT_1);
	save_int_5 = GetIntVec(AUTO_INT_5);
	
	// Disabling of Auto-Int 1 and 5 to aviod displaying of the alpha-, diamond-,
	// second-, shift-symbols in the status line
	SetIntVec(AUTO_INT_1, DUMMY_HANDLER);   // redirect auto-int 1 to "nothing"
	SetIntVec(AUTO_INT_5, DUMMY_HANDLER);   // redirect auto-int 5 to "nothing"

	LCD_save(screen);
		
	if (!GrayOn())
		return;

	mode = FALSE;

	do {
		// Load data from file
		if (!Load())
			memset(savload.wininfo, FALSE, (MAX_LEVELS)*(sizeof(BOOL)));
		
		time = 10;
		
		// Start playing the game
		options = DoIntro(mode);
		if (!options.mode)
			ExitTairo();
		
		mode = TRUE;
		
		GamePlay(options);
		
		Save(&savload);
	
		if (timeout) continue;
	
		// Ask the user if he wants to play again
		DrawBox();
		GrayDrawStrExt(0, (LCD_HEIGHT/2)-3, "Play again?", A_CENTERED | A_SHADOWED | A_XOR, F_4x6);
	
		do {
			key = Key_Wait();
		
			if (key == KEY_ENTER)
				break;
			
			if (key == KEY_ESC)
				ExitTairo();
		
		} while (TRUE);
		
	} while (TRUE);
}